==> qtmobilehotspot_0.3.4.tar.gz: qtmobilehotspot-0.3.4/qtmhNetFix/libqtmhnetfix-fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>Plugin</name>
    <message>
        <location filename="src/plugin.cpp" line="40"/>
        <source>Net Fixer</source>
        <translation>Fix réseau</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="52"/>
        <source>This plugin embeds several functions for fixing general hotspot slowdowns.</source>
        <translation>Ce plugin contient plusieurs fonctions pour corriger les problèmes classiques de ralentissement du hotspot.</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="53"/>
        <source>You may try them and see if they help.</source>
        <translation>Vous pouvez les essayer en cas de problème sur le hotspot.</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation type="obsolete">Configurer</translation>
    </message>
    <message>
        <source>Please stop the hotspot before configuring.</source>
        <translation type="obsolete">Veuillez-arrêter le hotspot avant de configurer.</translation>
    </message>
</context>
<context>
    <name>PluginGUI</name>
    <message>
        <location filename="src/plugingui.cpp" line="13"/>
        <source>No change</source>
        <translation>Ne pas changer</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="14"/>
        <source>2G only</source>
        <translation>2G seulement</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="15"/>
        <source>3G only</source>
        <translation>3G seulement</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="16"/>
        <source>2G/3G</source>
        <translation>2G/3G</translation>
    </message>
</context>
<context>
    <name>PluginGUIClass</name>
    <message>
        <location filename="src/plugingui.ui" line="14"/>
        <source>Fix networking...</source>
        <translation>Fix réseau...</translation>
    </message>
    <message>
        <source>Those checks are done periodically, and increase battery consumption.</source>
        <translation type="obsolete">Ces vérifications sont faites régulièrement et consomment de l&apos;énergie.</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="45"/>
        <source>Those functions may increase battery consumption.</source>
        <translation>Ces fonctions peuvent augmenter la consommation d&apos;énergie.</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="68"/>
        <source>Wifi : Ensure the interface is up when using WifiTo2G3G</source>
        <oldsource>Wifi : Ensure the interface is up when using WifiToGPRS</oldsource>
        <translation>Wifi : Maintenir l&apos;interface allumée en mode WifiVers2G3G</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="182"/>
        <source>Wifi : Disable power-saving in USBToWifi (restore it in the Wifi connections panel if a crash occurs)</source>
        <translation>Wifi : Désactiver l&apos;économie d&apos;énergie en USBVersWifi (restaurer dans les paramètres de connexion Wifi si un crash a lieu)</translation>
    </message>
    <message>
        <source>Wifi : Disable power-saving in USBToWifi (restore it in the control panel if a crash occurs)</source>
        <oldsource>Wifi : Disable power-saving when using USBToWifi</oldsource>
        <translation type="obsolete">Wifi : Désactiver l&apos;économie d&apos;énergie en USBVersWifi (restaurer dans les paramètres de connexion Wifi si un crash a lieu)</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="114"/>
        <source>Ping this server :</source>
        <translation>Pinger ce serveur :</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="172"/>
        <source>2G/3G switcher :</source>
        <translation>Switch 2G/3G :</translation>
    </message>
    <message>
        <source>GPRS : 2G/3G switcher :</source>
        <oldsource>GPRS : 2g/3g switcher :</oldsource>
        <translation type="obsolete">GPRS : Switch 2G/3G :</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="104"/>
        <source>2G/3G : Keep the connection alive by pinging a server</source>
        <oldsource>GPRS : Keep the connection alive by pinging a server</oldsource>
        <translation>2G/3G : Garder la connexion active en pingant un serveur</translation>
    </message>
    <message>
        <source>GPRS : Ping this server :</source>
        <translation type="obsolete">GPRS : Pinger ce serveur :</translation>
    </message>
    <message>
        <source>Disable Wifi power-saving when using USBtoWifi</source>
        <translation type="obsolete">Désactiver l&apos;économie d&apos;énergie en mode USBversWifi</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">Défaut</translation>
    </message>
</context>
</TS>

==> qtmobilehotspot_0.3.5.tar.gz: qtmobilehotspot-0.3.5/qtmhNetFix/libqtmhnetfix-fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>Plugin</name>
    <message>
        <location filename="src/plugin.cpp" line="39"/>
        <source>Net Fixer</source>
        <translation>Fix réseau</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="51"/>
        <source>This plugin embeds several functions for fixing general hotspot slowdowns.</source>
        <translation>Ce plugin contient plusieurs fonctions pour corriger les problèmes classiques de ralentissement du hotspot.</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="52"/>
        <source>You may try them and see if they help.</source>
        <translation>Vous pouvez les essayer en cas de problème sur le hotspot.</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation type="obsolete">Configurer</translation>
    </message>
    <message>
        <source>Please stop the hotspot before configuring.</source>
        <translation type="obsolete">Veuillez-arrêter le hotspot avant de configurer.</translation>
    </message>
</context>
<context>
    <name>PluginGUI</name>
    <message>
        <source>No change</source>
        <translation type="obsolete">Ne pas changer</translation>
    </message>
    <message>
        <source>2G only</source>
        <translation type="obsolete">2G seulement</translation>
    </message>
    <message>
        <source>3G only</source>
        <translation type="obsolete">3G seulement</translation>
    </message>
    <message>
        <source>2G/3G</source>
        <translation type="obsolete">2G/3G</translation>
    </message>
</context>
<context>
    <name>PluginGUIClass</name>
    <message>
        <location filename="src/plugingui.ui" line="14"/>
        <source>Fix networking...</source>
        <translation>Fix réseau...</translation>
    </message>
    <message>
        <source>Those checks are done periodically, and increase battery consumption.</source>
        <translation type="obsolete">Ces vérifications sont faites régulièrement et consomment de l&apos;énergie.</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="45"/>
        <source>Those functions may increase battery consumption.</source>
        <translation>Ces fonctions peuvent augmenter la consommation d&apos;énergie.</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="68"/>
        <source>Wifi : Ensure the interface is up when using WifiTo2G3G</source>
        <oldsource>Wifi : Ensure the interface is up when using WifiToGPRS</oldsource>
        <translation>Wifi : Maintenir l&apos;interface allumée en mode WifiVers2G3G</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="123"/>
        <source>Wifi : Disable power-saving in USBToWifi (restore it in the Wifi connections panel if a crash occurs)</source>
        <translation>Wifi : Désactiver l&apos;économie d&apos;énergie en USBVersWifi (restaurer dans les paramètres de connexion Wifi si un crash a lieu)</translation>
    </message>
    <message>
        <source>Wifi : Disable power-saving in USBToWifi (restore it in the control panel if a crash occurs)</source>
        <oldsource>Wifi : Disable power-saving when using USBToWifi</oldsource>
        <translation type="obsolete">Wifi : Désactiver l&apos;économie d&apos;énergie en USBVersWifi (restaurer dans les paramètres de connexion Wifi si un crash a lieu)</translation>
    </message>
    <message>
        <source>Ping this server :</source>
        <translation type="obsolete">Pinger ce serveur :</translation>
    </message>
    <message>
        <source>2G/3G switcher :</source>
        <translation type="obsolete">Switch 2G/3G :</translation>
    </message>
    <message>
        <source>GPRS : 2G/3G switcher :</source>
        <oldsource>GPRS : 2g/3g switcher :</oldsource>
        <translation type="obsolete">GPRS : Switch 2G/3G :</translation>
    </message>
    <message>
        <source>2G/3G : Keep the connection alive by pinging a server</source>
        <oldsource>GPRS : Keep the connection alive by pinging a server</oldsource>
        <translation type="obsolete">2G/3G : Garder la connexion active en pingant un serveur</translation>
    </message>
    <message>
        <source>GPRS : Ping this server :</source>
        <translation type="obsolete">GPRS : Pinger ce serveur :</translation>
    </message>
    <message>
        <source>Disable Wifi power-saving when using USBtoWifi</source>
        <translation type="obsolete">Désactiver l&apos;économie d&apos;énergie en mode USBversWifi</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">Défaut</translation>
    </message>
</context>
</TS>
